==> haskell-blaze-markup-0.8.3.0-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-3lhSB69YCfDDQ7BetUpwCx
key:                  blaze-markup-0.8.3.0-3lhSB69YCfDDQ7BetUpwCx
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  bb032f68182efdd0fea92bd99892b471
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.2.8/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-3lhSB69YCfDDQ7BetUpwCx
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.3.0-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-6XpAp6edGaj5nW8WYpqqy9
key:                  blaze-markup-0.8.3.0-6XpAp6edGaj5nW8WYpqqy9
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  89eb6ecf9c28cb75225bce8945f214b1
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.2.8/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-6XpAp6edGaj5nW8WYpqqy9
depends:
    base-4.16.4.0 blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
